/*
 * WalletLockImpl.java
 *
 * Copyright 2014 the curewallet.org.
 * http://www.curewallet.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.curewallet.lib.api.impl;

import org.curewallet.lib.api.AbstractCoinAPI;
import org.curewallet.lib.api.CoinAPIException;
import org.curewallet.lib.api.WalletLock;
import org.curewallet.lib.api.response.WalletLockResponseObject;
import org.curewallet.lib.api.result.WalletLockResult;
import org.curewallet.lib.jsonrpc.JsonRPCClient;
import org.curewallet.lib.jsonrpc.JsonRPCv1RequestObject;

/**
 * 
 * 
 * @author Nezumi Kozo
 * @since 1.0
 */
public class WalletLockImpl extends AbstractCoinAPI implements WalletLock {

	protected static final String METHOD = "walletlock";
	
	/**
	 * 
	 * @since 1.0
	 */
	public WalletLockImpl() {
	}

	/*
	 * (非 Javadoc)
	 * @see org.curewallet.lib.api.WalletLock#call(org.curewallet.lib.jsonrpc.JsonRPCClient)
	 * @since 1.0
	 */
	public WalletLockResult call(JsonRPCClient jsonRPCClient) throws CoinAPIException {
		try {
			if (jsonRPCClient == null) {
				throw new NullPointerException("jsonRPCClient is null.");
			}

			// request
			JsonRPCv1RequestObject requestObject = new JsonRPCv1RequestObject();
			requestObject.setMethod(METHOD);

			// JSON-RPC call
			return jsonRPCClient.call(requestObject, WalletLockResponseObject.class).getResultObject();

		} catch (Exception e) {
			// JsonRPCException
			throw new CoinAPIException("Error: " + e.getMessage(), e);
		}
	}

}
